.. PyPEC documentation master file, created by
   sphinx-quickstart on Sat Dec 13 21:40:31 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PyPEC's documentation!
=================================

.. toctree::
   :titlesonly:
   :maxdepth: 1
   
   getting_started/index.rst
   user_guide/index.rst
   releases/index.rst
   api/index.rst
   bibliography/index.rst
   
   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

